;+
;NAME:
;       plot_trace
;PURPOSE:
;       Plot timeline of average counts in selected images
;SAMPLE CALLING SEQUENCE:
;       plot_trace,struct  [,wave=wave] [,nx=nx] [,/nofilter]
;INPUTS:
;       struct  - existing index or catalog structure
;Keyword Inputs:
;       wavelength  - wavelength of selected images (def = '1600')
;       nx          - size of selected images (def = 1024)
;       nofilter    - if set, do not filter for bad data
;       timerange   - timerange of plot
;PROCEDURE:
;       normalize the selected waveband
;       divide by exposure after subtracting the dark pedestal
;       correct time of images be SUBTRACTING half of exposure time
;HISTORY:
;       Written    Nov-98 by R.D.Bentley
;-



;	normalize the selected waveband
;	divide by exposure after subtracting the dark pedestal

pro	plot_trace,struct,wavelength=wavelength, nx=nx, nofilter=nofilter, out_sel=out_sel, $
		timerange=timerange, xstyle=xstyle, _extra=_extra

wave = '1600'
if keyword_set(wavelength) then wave = strtrim(string(wavelength),2)
naxis = 1024
if keyword_set(nx) then naxis = nx

match = where(struct.wave_len eq wave and struct.naxis1 eq naxis)
if match(0) eq -1 then begin
   box_message,['** NO data matches the parameters **:', $
               string(wave,naxis,format='(a,i6)')]
   return
endif

;	filter for good data
good = indgen(n_elements(match))
if not keyword_set(nofilter) then begin
;	should we search on normalized .img_dev?????
   good = trace_data_filter(struct(match))
endif
help,struct,match,good

good_struct = struct(match(good))

;	normalize the selected waveband
;	divide by exposure after subtracting the CCD readout pedestal
ccd_pedestal = 87
counts = (good_struct.img_avg-ccd_pedestal)/good_struct.sht_mdur

;       Time in the data are end when the shutter CLOSES - correct this!
end_times = anytim2ints(good_struct)
mid_times = addtime(end_times,delta=-good_struct.sht_mdur/2./60.)

;	plot against time
title='TRACE '+wave+' A'
utplot,mid_times,counts,timerange=timerange,xstyle=xstyle, $
	title=title,_extra=_extra

out_sel = match(good)

end
